<?php   
/**
 *Grace Mag functions and definitions
 *
 * @package Grace Mag
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'grace_mag_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.  
 */
function grace_mag_setup() {		
	global $content_width;   
    if ( ! isset( $content_width ) ) {
        $content_width = 680; /* pixels */
    }	

	load_theme_textdomain( 'grace-mag', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support('html5');
	add_theme_support( 'post-thumbnails' );	
	add_theme_support( 'title-tag' );	
	add_theme_support( 'custom-logo', array(
		'height'      => 50,
		'width'       => 150,
		'flex-height' => true,
	) );
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'grace-mag' ),
		'footer' => __( 'Footer Menu', 'grace-mag' ),				
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
} 
endif; // grace_mag_setup
add_action( 'after_setup_theme', 'grace_mag_setup' );
function grace_mag_widgets_init() { 	
	
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'grace-mag' ),
		'description'   => __( 'Appears on blog page sidebar', 'grace-mag' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Header Ad Widget', 'grace-mag' ),
		'description'   => __( 'Appears on the site header', 'grace-mag' ),
		'id'            => 'header-ad-widget',
		'before_widget' => '<aside id="%1$s" class="head-rightpart %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="header-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'grace-mag' ),
		'description'   => __( 'Appears on footer', 'grace-mag' ),
		'id'            => 'footer-widget-1',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'grace-mag' ),
		'description'   => __( 'Appears on footer', 'grace-mag' ),
		'id'            => 'footer-widget-2',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'grace-mag' ),
		'description'   => __( 'Appears on footer', 'grace-mag' ),
		'id'            => 'footer-widget-3',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
}
add_action( 'widgets_init', 'grace_mag_widgets_init' );

if ( ! function_exists( 'grace_mag_get_single_post_category' ) ) :

	/**
	 * Get single post category.
	 *
	 * @since 1.0.0
	 *
	 * @param int $id Post ID.
	 * @return array Category detail.
	 */
	function grace_mag_get_single_post_category( $id ) {
		$output = array();

		$cats = get_the_category( $id );

		if ( ! empty( $cats ) ) {
			$cat  = array_shift( $cats );
			$output['name'] = $cat->name;
			$output['slug'] = $cat->name;
			$output['url']  = get_term_link( $cat );
		}

		return $output;
	}

endif;


function grace_mag_font_url(){
		$font_url = '';		
		
		/* Translators: If there are any character that are not
		* supported by Roboto, trsnalate this to off, do not
		* translate into your own language.
		*/
		$roboto = _x('on','Roboto:on or off','grace-mag');
		
		/* Translators: If there are any character that are not
		* supported by Oswald, trsnalate this to off, do not
		* translate into your own language.
		*/
		$oswald = _x('on','Oswald:on or off','grace-mag');					
		
		if('off' !== $roboto || 'off' !== $oswald  ){
			$font_family = array();
			
			if('off' !== $roboto){
				$font_family[] = 'Roboto:300,400,600,700,800,900';
			}
			
			if('off' !== $oswald){
				$font_family[] = 'Oswald:300,400,700';
			}
					
						
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);
			
			$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		}
		
	return $font_url;
	}


function grace_mag_scripts() {
	wp_enqueue_style('grace-mag-font', grace_mag_font_url(), array());
	wp_enqueue_style( 'grace-mag-basic-style', get_stylesheet_uri() );	
	wp_enqueue_style( 'nivo-slider', get_template_directory_uri()."/css/nivo-slider.css" );
	wp_enqueue_style( 'grace-mag-responsive', get_template_directory_uri()."/css/responsive.css" );	
	wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'grace-mag-editable', get_template_directory_uri() . '/js/editable.js' );
	
	wp_enqueue_style( 'li-scroller', get_template_directory_uri()."/css/li-scroller.css" );
	wp_enqueue_script( 'li-scroller', get_template_directory_uri() . '/js/jquery.li-scroller.1.0.js' );

	
	wp_enqueue_style( 'owl-style', get_template_directory_uri().'/rotator/js/owl.carousel.css' );
	wp_enqueue_script( 'owljs', get_template_directory_uri().'/rotator/js/owl.carousel.js', array('jquery') );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'grace_mag_scripts' );

function grace_mag_ie_stylesheet(){
	// Load the Internet Explorer specific stylesheet.
	wp_enqueue_style('grace-mag-ie', get_template_directory_uri().'/css/ie.css', array( 'grace-mag-style' ), '20160928' );
	wp_style_add_data('grace-mag-ie','conditional','lt IE 10');
	
	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'grace-mag-ie8', get_template_directory_uri() . '/css/ie8.css', array( 'grace-mag-style' ), '20160928' );
	wp_style_add_data( 'grace-mag-ie8', 'conditional', 'lt IE 9' );

	// Load the Internet Explorer 7 specific stylesheet.
	wp_enqueue_style( 'grace-mag-ie7', get_template_directory_uri() . '/css/ie7.css', array( 'grace-mag-style' ), '20160928' );
	wp_style_add_data( 'grace-mag-ie7', 'conditional', 'lt IE 8' );	
	}
add_action('wp_enqueue_scripts','grace_mag_ie_stylesheet');

define('GRACE_MAG_THEME_DOC','https://gracethemes.com/documentation/gracemag-doc/#homepage-lite','grace-mag');
define('GRACE_MAG_PROTHEME_URL','https://gracethemes.com/themes/blog-wordpress-theme/','grace-mag');
define('GRACE_MAG_LIVE_DEMO','https://www.gracethemes.com/demo/grace-mag/','grace-mag');

if ( ! function_exists( 'grace_mag_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function grace_mag_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom template for about theme.
 */
if ( is_admin() ) { 
require get_template_directory() . '/inc/about-themes.php';
}

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';